# modern-urwid
An urwid library for creating TUIs from XML and CSS

[![Documentation Status](https://readthedocs.org/projects/modern_urwid/badge/?version=latest)](https://modern-urwid.readthedocs.io/en/latest/?badge=latest) [![PyPI](https://img.shields.io/pypi/v/modern_urwid?label=pypi%20package)](https://pypi.org/project/modern-urwid/) ![PyPI - Downloads](https://img.shields.io/pypi/dm/modern_urwid)

## Installation
Instal with:  
`pip install modern-urwid`

## Docs
The docs can be accessed [here](https://modern-urwid.readthedocs.io/en/latest/).
